@@ -3,25 +3,32 @@ import requests
 import json
 from urllib.parse import urlencode
 import os
+import glob
+import base64
 import xmltodict
 
 
 class te_services:
-    def __init__(self, confJSON=None):
+    def __init__(self, confJSONPath=None):
         this_dir, this_filename = os.path.split(__file__)
         te_constant_path = os.path.join(this_dir, "te_constant.json")
         te_config_path = os.path.join(this_dir, "te_config.json")
+        local_path = "tetest/te_config.json"
+        for arg in sys.argv:
+            if "--Config=" in arg:
+                local_path = arg.split("=")[1]
         with open(te_constant_path, "r") as cons:
             self.te_constant = json.load(cons)
-        if confJSON:
-            self.te_config_json = confJSON
-        elif os.path.exists("tetest/te_config.json"):
-            with open("tetest/te_config.json", "r") as con:
+        if confJSONPath:
+            local_path = confJSONPath
+        if os.path.exists(local_path):
+            with open(local_path, "r") as con:
                 self.te_config_json = json.load(con)
         else:
             # load default config file in current folder: te_config.json
             with open(te_config_path, "r") as con:
                 self.te_config_json = json.load(con)
+        self.e2eDataFolder = os.path.dirname(local_path)
         # replace the parameter from argument
         # --TaskID, --Token, --BuildID, --TimeSpan
         for arg in sys.argv:
@@ -117,7 +124,7 @@ class te_services:
                                   queryJSON=None, projectName=None, isE2E=False):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
-        requestUR = self.te_config_json["Server"]+ "/" + \
+        requestUR = self.te_config_json["Server"] + "/" + \
             self.te_constant["ServerAPI"]["PROJECT_DATA"] + \
             "/" + _projectName + \
             "/" + tableName + \
@@ -315,12 +322,47 @@ class te_services:
 
     def uploadJSONReport(self, projectName=None):
         # get report
-        reportPath = os.path.join(self.te_config_json.get("Report").get(
-            "Path"), self.te_config_json.get("Report").get("File"))
-        if os.path.exists(reportPath):
-            reportJSON = self.converXMLReportToJSON(reportPath)
+        # if file is "", scan all of the xml files;
+        reportFileName = self.te_config_json.get("Report").get("File")
+        reportFolderPath = self.te_config_json.get("Report").get("Path")
+        imagePath = self.te_config_json.get("Report").get("ImagePath")
+        reportJSONList=[]
+        if self.te_config_json["Agent"] == "NOSE":
+            if reportFileName == None or reportFileName == "":
+                if os.path.exists(reportFolderPath):
+                    reportXmlList = glob.glob(reportFolderPath + '/*.xml')
+                    for file in reportXmlList:
+                        print("Report File:"+file)
+                        reportObj = self.converXMLReportToJSON(file)
+                        # inser the report
+                        if reportObj.get("TestCase") != None:
+                            # load image
+                            steps = reportObj.get("TestCase").get("Steps")
+                            for step in steps["Step"]:
+                                screenshot = step.get("Screenshot")
+                                if screenshot != None:
+                                    screenshot = screenshot.replace("\\", "/")
+                                    screenshotPath = os.path.join(
+                                        imagePath, screenshot)
+                                    if os.path.exists(screenshotPath):
+                                        with open(screenshotPath, "rb") as f:
+                                            base64_data = base64.b64encode(
+                                                f.read())
+                                            step["Screenshot"] = base64_data
+                            reportJSONList.append(reportObj)
+                else:
+                    print("[TE-Info]: NO report file found")
+                    return
+            else:
+                print("[TE-Info]: NO report file found")
+                return
         else:
-            print("[TE-Info]: NO report file found")
+            reportPath = os.path.join(reportFolderPath, reportFileName)
+            if os.path.exists(reportPath):
+                reportJSONList.append(self.converXMLReportToJSON(reportPath))
+            else:
+                print("[TE-Info]: NO report file found")
+
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
         # if e2e, should use the E2E sources project name
@@ -350,11 +392,11 @@ class te_services:
             jobid = self.te_config_json.get("JobInfo").get("_id")
         bodyJSON = {
             "jobid": jobid,
-            "report": reportJSON,
+            "report": {},
             "data": []
         }
         # get the e2e data json list
-        dataFilePath = "tetest/teE2EData_" + \
+        dataFilePath = self.e2eDataFolder+"/teE2EData_" + \
             self.te_config_json["BuildID"]+".json"
         jString = ''
         if os.path.exists(dataFilePath):
@@ -365,7 +407,9 @@ class te_services:
             bodyJSON["data"] = dataList.get("data")
             # ==todo: clean data, before the script stateble
         # upload report
-        result = requests.post(requestUR, json=bodyJSON, headers=self.headers)
+        for reportObjIndex in reportJSONList:
+            bodyJSON["report"]=reportObjIndex
+            result = requests.post(requestUR, json=bodyJSON, headers=self.headers)
         reportData = json.loads(result.text)
         return reportData
 
@@ -389,7 +433,7 @@ class te_services:
             data["methoname"] = methodName
             data["filename"] = fileName
         # check if json file in tetest
-        dataFilePath = "tetest/teE2EData_" + \
+        dataFilePath = self.e2eDataFolder+"/teE2EData_" + \
             self.te_config_json["BuildID"]+".json"
         jString = ''
         if os.path.exists(dataFilePath):
